SensorData class

Typed data model for 3-axis sensor streams (accelerometer, gyroscope, magnetometer, linear acceleration). Author: Bharathwaj

Constructors

SensorData({required double x, required double y, required double z, required int timestamp})
const
SensorData.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final
x double
final
y double
final
z double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited