SensorInfo class

Sensor information returned by AllDeviceSensors.getSensors.

Constructors

SensorInfo({required String name, required String vendor, required int type, required int version, required double power, required double resolution, required double maxRange})
const
SensorInfo.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRange double
final
name String
final
power double
final
resolution double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
final
vendor String
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited