SingleSensorData class

Typed data model for single-value sensor streams (barometer, proximity, light, step counter).

Constructors

SingleSensorData({required double value, required int timestamp})
const
SingleSensorData.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final
value double
The sensor reading value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited