RotationData class
Typed data model for rotation vector stream (x, y, z, w — quaternion).
Constructors
- RotationData({required double x, required double y, required double z, required double w, required int timestamp})
-
const
-
RotationData.fromMap(Map<
String, dynamic> map) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited