SensorData class
Typed data model for 3-axis sensor streams (accelerometer, gyroscope, magnetometer, linear acceleration). Author: Bharathwaj
Constructors
- SensorData({required double x, required double y, required double z, required int timestamp})
-
const
-
SensorData.fromMap(Map<
String, dynamic> map) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited