SensorInterval enum
Controls how fast sensor data is delivered.
- Inheritance
- Available extensions
Values
- normal → const SensorInterval
-
~200ms — suitable for normal UI updates
- ui → const SensorInterval
-
~60ms — suitable for UI animations
- game → const SensorInterval
-
~20ms — suitable for games
- fastest → const SensorInterval
-
As fast as the hardware allows
Properties
- androidDelay → int
-
Available on SensorInterval, provided by the SensorIntervalValue extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- iosInterval → double
-
Available on SensorInterval, provided by the SensorIntervalValue extension
no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SensorInterval> - A constant List of the values in this enum, in order of their declaration.